@@ -10,6 +10,8 @@
 
 #include <aws/common/logging.h>
 
+AWS_PUSH_SANE_WARNING_LEVEL
+
 struct aws_log_channel;
 struct aws_log_formatter;
 struct aws_log_writer;
@@ -29,7 +31,9 @@ enum aws_io_log_subject {
     AWS_LS_IO_SHARED_LIBRARY,
     AWS_LS_IO_EXPONENTIAL_BACKOFF_RETRY_STRATEGY,
     AWS_LS_IO_STANDARD_RETRY_STRATEGY,
+    AWS_LS_IO_PKCS11,
     AWS_IO_LS_LAST = AWS_LOG_SUBJECT_END_RANGE(AWS_C_IO_PACKAGE_ID)
 };
+AWS_POP_SANE_WARNING_LEVEL
 
 #endif /* AWS_IO_LOGGING_H */
